@@ -32,7 +32,7 @@ public class CodelistDocument implements SDMXDocument {
 	 * {@inheritDoc}
 	 */
 	public String getDescription() {
-		return "Select this document if you want to retrive codelist";
+		return "Select this document if you want to retrieve codelist";
 	}
 
 	/**
