@@ -2,10 +2,9 @@ package org.gcube.portlets.user.td.gwtservice.shared.task;
 
 import java.io.Serializable;
 
-
 import org.gcube.data.analysis.tabulardata.service.operation.Task;
-import org.gcube.portlets.user.td.gwtservice.shared.UIOperationsId;
 import org.gcube.portlets.user.td.widgetcommonevent.shared.TRId;
+import org.gcube.portlets.user.td.widgetcommonevent.shared.operations.UIOperationsId;
 
 /**
  * 
